@@ -1,6 +1,7 @@
 # encoding=utf-8
 
 from argparse import SUPPRESS
+from collections import deque
 from datetime import datetime, timezone
 from getpass import getpass
 from os import path, urandom
@@ -230,7 +231,9 @@ def upload(connection_or_endpoint, image_id, image_file, key,
 
         # start image conversion, redirect stderr to stdout (text mode)
         process = Popen(command_line, universal_newlines=True, stdout=PIPE, stderr=STDOUT)  # nosec
-        console_lines = []
+        # limit number of lines output to 1024, but count the total number of lines captured
+        console_lines = deque(maxlen=1024)
+        num_lines = 0
         # process.communicate blocks, instead read from process' standard out until EOF
         for line in iter(process.stdout.readline, ''):
             # separate regular log lines from bits of info we want
@@ -248,12 +251,15 @@ def upload(connection_or_endpoint, image_id, image_file, key,
                 line = line.strip()
                 log.debug('log output from image tool: {}', line)
                 console_lines.append(line)
+                num_lines += 1
 
         message = 'conversion process (image id {image_id}) terminated with return code {return_code}, ' \
-                  'output follows\n---\n{output}'
+                  'output follows {tail}\n---\n{output}'
+        tail = '' if len(console_lines) == num_lines else f'(last {len(console_lines)} of total {num_lines} lines)'
         if process.wait() != 0:
             raise ValueError(message.format(image_id=image_id if image_id is not None else 'unknown',
                                             return_code=process.returncode,
+                                            tail=tail,
                                             output='\n'.join(console_lines)))
 
     def do_upload(connection):
